%define major   0
%define libname %mklibname multipath %{major}
%define libmp_c %mklibname mpathcmd %{major}
%define libmp_p %mklibname mpathpersist %{major}
%define libmp_v %mklibname mpathvalid %{major}
%define libdmmp %mklibname dmmp %{major}
%define devname %mklibname multipath-tools -d
%define devdmmp %mklibname dmmp -d

%define systemd_ver %(pkg-config --modversion systemd 2> /dev/null)

%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}devel\\(libmpathcmd

Name:           multipath-tools
# This URL is no longer available
URL:            http://christophe.varoqui.free.fr/
License:        GPLv2
Group:          System/Kernel and hardware
Version:        0.8.8
Release:        %mkrel 3
Summary:        Tools to manage multipathed devices with the device-mapper
# The source for this package was pulled from upstream's git repo.  Use the
# following command to generate the tarball
# curl "https://git.opensvc.com/?p=multipath-tools/.git;a=snapshot;h=refs/tags/0.8.4;sf=tgz" -o multipath-tools-0.8.4.tgz
Source0:        https://github.com/opensvc/multipath-tools/archive/%{version}/multipath-tools-%{version}.tar.gz
Patch0021:      0021-RH-Fix-nvme-compilation-warning.patch
Patch0040:      0040-multipathd-ignore-duplicated-multipathd-command-keys.patch
Patch0041:      0041-multipath-tools-use-run-instead-of-dev-shm.patch

BuildRequires:  libaio-devel
BuildRequires:  libsysfs-devel
BuildRequires:  userspace-rcu-devel
BuildRequires:  pkgconfig(devmapper)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(readline)
BuildRequires:  pkgconfig(libsystemd)

Requires:       dmsetup
Requires:       kpartx = %{version}
Conflicts:      kpartx < 0.4.8-16
Provides:       device-mapper-multipath = %{version}-%{release}

%{?systemd_requires}

%description
This package provides the tools to manage multipathed devices by
instructing the device-mapper multipath module what to do. The tools
are:

- multipath: scan the system for multipathed devices, assembles them
  and update the device-mapper's maps

- multipathd: wait for maps events, then execs multipath

- devmap-name: provides a meaningful device name to udev for devmaps

- kpartx: maps linear devmaps upon device partitions, which makes
  multipath maps partitionable

%package -n %{libname}
Summary:        Shared multipath library for %{name}
Group:          System/Libraries
Conflicts:      multipath-tools < 0.8.0-1

%description -n %{libname}
Shared multipath library for %{name}.

%package -n %{libmp_c}
Summary:        Shared mpathcmd library for %{name}
Group:          System/Libraries
Conflicts:      multipath-tools < 0.8.0-1

%description -n %{libmp_c}
Shared mpathcmd library for %{name}.

%package -n %{libmp_p}
Summary:        Shared mpathpersist library for %{name}
Group:          System/Libraries
Conflicts:      multipath-tools < 0.8.0-1

%description -n %{libmp_p}
Shared mpathpersist library for %{name}.

%package -n %{libmp_v}
Summary:        Shared mpathvalid library for %{name}
Group:          System/Libraries

%description -n %{libmp_v}
Shared mpathvalid library for %{name}.

%package -n %{devname}
Summary:        Development libraries and headers for %{name}
Group:          Development/C
Requires:       %{name} = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libmp_c} = %{version}-%{release}
Requires:       %{libmp_p} = %{version}-%{release}
Requires:	%{libmp_v} = %{version}-%{release}
Provides:       device-mapper-multipath-devel = %{version}-%{release}
Provides:       multipath-devel = %{version}-%{release}

%description -n %{devname}
This package contains the files need to develop applications that use
device-mapper-multipath's lbmpathpersist and libmpathcmd libraries.

%package -n kpartx
Summary:        Partition device manager for device-mapper devices
Group:          System/Kernel and hardware
Requires:       dmsetup
Conflicts:      multipath-tools < 0.4.8-16

%description -n kpartx
kpartx manages partition creation and removal for device-mapper devices.

%package -n %{libdmmp}
Summary:        device-mapper-multipath C API library
Group:          System/Libraries
Requires:       %{name} = %{version}-%{release}

%description -n %{libdmmp}
This package contains the shared library for the device-mapper-multipath
C API library.

%package -n %{devdmmp}
Summary:        device-mapper-multipath C API library headers
Group:          Development/C
Requires:       %{libdmmp} = %{version}-%{release}
Provides:       libdmmp-devel = %{version}-%{release}

%description -n %{devdmmp}
This package contains the files needed to develop applications that use
device-mapper-multipath's libdmmp C API library.

%prep
%autosetup -p1

%build
%make_build OPTFLAGS="%{optflags}" SYSTEMD=%{systemd_ver}

%define _libmpathdir %{_libdir}/multipath
%define _pkgconfdir %{_libdir}/pkgconfig

%install
%make_install \
	syslibdir=%{_libdir} \
	usrlibdir=%{_libdir} \
	libdir=%{_libmpathdir} \
	unitdir=%{_unitdir} \
	includedir=%{_includedir} \
	pkgconfdir=%{_pkgconfdir} \
	tmpfilesdir=%{_tmpfilesdir}

rm -rf %{buildroot}%{_sysconfig}/hotplug.d

%preun
%systemd_preun multipathd.service

%postun
%systemd_postun_with_restart multipathd.service

%post
%systemd_post multipathd.service

%files
%license LICENSES/*
%doc README.md
/sbin/multipath
/sbin/multipathd
/sbin/mpathpersist
%{_mandir}/man?/*dmmp*
%{_mandir}/man?/multipath*
%{_mandir}/man?/mpath*
%dir %{_libmpathdir}
%{_libmpathdir}/*
%{_tmpfilesdir}/multipath.conf
%{_unitdir}/multipathd.service
%{_unitdir}/multipathd.socket
%{_udevrulesdir}/*path.rules
%{_udevrulesdir}/*part*.rules

%files -n %{libname}
%doc README.md
%license LICENSES/*
%{_libdir}/libmultipath.so.%{major}{,.*}

%files -n %{libmp_c}
%license LICENSES/*
%{_libdir}/libmpathcmd.so.%{major}{,.*}

%files -n %{libmp_p}
%license LICENSES/*
%{_libdir}/libmpathpersist.so.%{major}{,.*}

%files -n %{libmp_v}
%license LICENSES/*
%{_libdir}/libmpathvalid.so.%{major}{,.*}

%files -n %{devname}
%license LICENSES/*
%{_libdir}/libmultipath.so
%{_libdir}/libmpathpersist.so
%{_libdir}/libmpathcmd.so
%{_libdir}/libmpathvalid.so
%{_includedir}/mpath_cmd.h
%{_includedir}/mpath_persist.h
%{_includedir}/mpath_valid.h
%{_mandir}/man3/mpath_persistent_reserve_in.3.*
%{_mandir}/man3/mpath_persistent_reserve_out.3.*

%files -n kpartx
%license LICENSES/*
/sbin/kpartx
%{_udevrulesdir}/*kpartx.rules
%{_prefix}/lib/udev/kpartx_id
%{_mandir}/man8/kpartx.8*

%files -n %{libdmmp}
%license LICENSES/*
%{_libdir}/libdmmp.so.%{major}{,.*}

%files -n %devdmmp
%license LICENSES/*
%{_libdir}/libdmmp.so
%dir %{_includedir}/libdmmp
%{_includedir}/libdmmp/*
%{_mandir}/man3/dmmp_*
%{_mandir}/man3/libdmmp.h.3.*
%{_pkgconfdir}/libdmmp.pc


%changelog
* Fri Mar 15 2024 ns80 <ns80> 0.8.8-3.mga10
+ Revision: 2049999
- port patches from Fedora for CVE-2022-4197[34] (mga#31017)

* Fri Apr 01 2022 umeabot <umeabot> 0.8.8-2.mga9
+ Revision: 1838142
- Mageia 9 Mass Rebuild

* Sun Jan 30 2022 mrambo3501 <mrambo3501> 0.8.8-1.mga9
+ Revision: 1770629
- version 0.8.8

* Wed Dec 01 2021 wally <wally> 0.8.7-1.mga9
+ Revision: 1760438
- new version 0.8.7
- new mpathvalid library
- rebuild for userspace-rcu 0.13.0

* Sun Nov 29 2020 luigiwalser <luigiwalser> 0.8.5-2.mga8
+ Revision: 1650342
- rebuild for json-c

* Wed Nov 18 2020 luigiwalser <luigiwalser> 0.8.5-1.mga8
+ Revision: 1647152
- 0.8.5
- update URL
- remove upstreamed patches
- rediff patch 23

* Fri Jun 19 2020 daviddavid <daviddavid> 0.8.4-1.mga8
+ Revision: 1596605
- new version: 0.8.4
- add some fedora patches
- kpartx also requires dmsetup (mga#26812)

* Tue Feb 18 2020 umeabot <umeabot> 0.8.0-4.mga8
+ Revision: 1542195
- Mageia 8 Mass Rebuild

* Sat Jan 04 2020 luigiwalser <luigiwalser> 0.8.0-3.mga8
+ Revision: 1475989
- rebuild for readline

* Sun Apr 14 2019 daviddavid <daviddavid> 0.8.0-2.mga7
+ Revision: 1389905
- fix dangling links

* Thu Apr 11 2019 daviddavid <daviddavid> 0.8.0-1.mga7
+ Revision: 1388204
- new version: 0.8.0
- split out all libraries in separate sub-pkg
- fix devel files in-non-devel-pkg

* Sat Jan 26 2019 ngompa <ngompa> 0.7.6-2.mga7
+ Revision: 1361027
- Fix scriptlet requires
- Add device-mapper-multipath Provides
- Small cleanups to the spec

* Mon Aug 27 2018 daviddavid <daviddavid> 0.7.6-1.mga7
+ Revision: 1254974
- rebuild for new json-c 0.13.1
+ kekepower <kekepower>
- Update to version 0.7.6

* Sat Mar 03 2018 tv <tv> 0.7.3-4.mga7
+ Revision: 1206407
- rebuild for new ircu

* Mon Feb 05 2018 tv <tv> 0.7.3-3.mga7
+ Revision: 1198990
- BR json-c-devel
- new release
- // build now works again
- adapt to /usrmove world
- split devel subpkg (with devel() deps)
- split new libddmp subpkgs

* Tue Jan 02 2018 wally <wally> 0.5.0-6.mga7
+ Revision: 1189452
- rebuild for new readline

* Tue Jun 07 2016 tv <tv> 0.5.0-5.mga6
+ Revision: 1020647
- adjust BRs for latest systemd

* Mon Feb 08 2016 umeabot <umeabot> 0.5.0-4.mga6
+ Revision: 944806
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.5.0-3.mga5
+ Revision: 739445
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.5.0-2.mga5
+ Revision: 682691
- Mageia 5 Mass Rebuild

* Tue Sep 09 2014 joequant <joequant> 0.5.0-1.mga5
+ Revision: 674126
- update to 0.5.0

* Fri Oct 18 2013 umeabot <umeabot> 0.4.9-3.mga4
+ Revision: 515103
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 cjw <cjw> 0.4.9-2.mga3
+ Revision: 373449
- move udev rules files to _udevrulesdir
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Mar 06 2012 tmb <tmb> 0.4.9-1.mga2
+ Revision: 220346
- drop merged patches
- update to 0.4.9

* Mon Feb 20 2012 tmb <tmb> 0.4.8-18.1.mga2
+ Revision: 211095
- kpartx: implement update option (-u) (mga #3960)

* Sat Jan 15 2011 blino <blino> 0.4.8-18.mga1
+ Revision: 19123
- imported package multipath-tools


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 0.4.8-18mdv2011.0
+ Revision: 606670
- rebuild

* Sat Feb 20 2010 Thomas Backlund <tmb@mandriva.org> 0.4.8-17mdv2010.1
+ Revision: 508762
- kpartx: deal with more than 256 minor numbers
- kpartx.rules: use current name of the device node

* Fri Feb 19 2010 Thomas Backlund <tmb@mandriva.org> 0.4.8-16mdv2010.1
+ Revision: 508452
- fix kpartx udev rule for dmraid
- move kpartx.rules and kpartx_id from multipath-tools to kpartx rpm

* Thu Aug 20 2009 Anssi Hannula <anssi@mandriva.org> 0.4.8-15mdv2010.0
+ Revision: 418368
- fix duplicated files between multipath-tools and kpartx
- require kpartx in multipath-tools

* Mon Aug 17 2009 Pascal Terjan <pterjan@mandriva.org> 0.4.8-14mdv2010.0
+ Revision: 417272
- Fix kpartx extended partition handling fix

* Tue Jul 28 2009 Pascal Terjan <pterjan@mandriva.org> 0.4.8-12mdv2010.0
+ Revision: 401386
- Avoid failure when pp_hp_sw gets installed before other executables
- Bump release due to misterious build failure
- Add missing conflict and drop useless provide

* Mon Jul 27 2009 Pascal Terjan <pterjan@mandriva.org> 0.4.8-9mdv2010.0
+ Revision: 400518
- Fix group of kpartx
- Split kpartx in a separate package, so that mkinitrd can require only it

* Mon Jul 20 2009 Eugeni Dodonov <eugeni@mandriva.com> 0.4.8-8mdv2010.0
+ Revision: 398031
- Updated init script to be LSB-compliant.

* Sun Jul 19 2009 Pascal Terjan <pterjan@mandriva.org> 0.4.8-7mdv2010.0
+ Revision: 397455
- Fix correctly scsi_id usage
- Add a few fedora patches (#52270, CVE-2009-0115)

* Tue Mar 17 2009 Guillaume Rousse <guillomovitch@mandriva.org> 0.4.8-5mdv2009.1
+ Revision: 356300
- rebuild for latest readline

* Mon Sep 29 2008 Thierry Vignaud <tv@mandriva.org> 0.4.8-4mdv2009.0
+ Revision: 289765
- include more doc (per #43925 request)
- make service executable (#43925)
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Mon Oct 22 2007 Thierry Vignaud <tv@mandriva.org> 0.4.8-1mdv2008.1
+ Revision: 101331
- adjust file list
- patch 0: fix build
- BuildRequires:  libaio-devel
- new release


* Sat Nov 25 2006 Thierry Vignaud <tvignaud@mandriva.com> 0.4.7-5mdv2007.0
+ Revision: 87151
- Import multipath-tools

* Sat Nov 25 2006 Thierry Vignaud <tvignaud@mandrakesoft.com> 0.4.7-5mdv2007.1
- rebuild for libdevmapper

* Mon Jul 03 2006 Emmanuel Andry <eandry@mandriva.org> 0.4.7-4mdv2007.0
- rebuild for libdevmapper

* Wed May 03 2006 Thierry Vignaud <tvignaud@mandriva.com> 0.4.7-3mdk
- fix buildrequires (thus fixing x86_64 build with iurt)

* Wed Apr 19 2006 Thierry Vignaud <tvignaud@mandriva.com> 0.4.7-2mdk
- fix buildrequires

* Fri Mar 31 2006 Thierry Vignaud <tvignaud@mandriva.com> 0.4.7-1mdk
- new release

* Wed Dec 07 2005 Nicolas Lécureuil <neoclust@mandriva.org> 0.4.6-2mdk
- Fix BuildRequires

* Wed Nov 16 2005 Thierry Vignaud <tvignaud@mandriva.com> 0.4.6-1mdk
- new release
- drop patch 0 (now useless)

* Wed Jun 29 2005 Pascal Terjan <pterjan@mandriva.org> 0.4.2.7-3mdk
- BuildRequires libdevmapper-devel
- PreReq -> Requires(post)

* Sat Mar 05 2005 Luca Berra <bluca@vodka.it> 0.4.2.7-2mdk 
- rebuild for new libdevmapper
- use a mandrakelinux initscript
- specfile cleanup

* Thu Jan 20 2005 Thierry Vignaud <tvignaud@mandrakesoft.com> 0.4.2.7-1mdk
- new release
- automatically updatable
- patch 0: fix build

* Thu Dec 23 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 0.4.2.0-1mdk
- new release

* Thu Nov 25 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 0.3.8-1mdk
- new release

* Fri Nov 05 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 0.3.6-1mdk
- initial releaee

